Skip to contents

Prints a compact summary of collections and layer metadata for a `wri_overview` object.

Usage

# S3 method for class 'wri_overview'
print(x, ...)

Arguments

x

A `wri_overview` object.

...

Additional arguments passed to the S3 method. Currently unused.

Value

Called for its side effect of printing a summary.