Prints a compact summary of collections and layer metadata for a `wri_overview` object.
Usage
# S3 method for class 'wri_overview'
print(x, ...)Prints a compact summary of collections and layer metadata for a `wri_overview` object.
# S3 method for class 'wri_overview'
print(x, ...)